# API Reference

## Workflows

```{eval-rst}
.. currentmodule:: ess.polarization

.. autosummary::
   :toctree: ../generated/classes
   :template: class-template.rst
   :recursive:

   CorrectionWorkflow
   He3CellWorkflow
   HalfPolarizedWorkflow
   PolarizationAnalysisWorkflow
   SupermirrorWorkflow
```

## Classes

```{eval-rst}
.. currentmodule:: ess.polarization

.. autosummary::
   :toctree: ../generated/classes
   :template: class-template.rst
   :recursive:

   Analyzer
   Depolarized
   DirectBeamBackgroundQRange
   DirectBeamNoCell
   DirectBeamQRange
   Down
   HalfPolarizedCorrectedData
   He3CellLength
   He3CellPressure
   He3DirectBeam
   He3FillingTime
   He3OpacityFunction
   He3PolarizationFunction
   He3TransmissionFunction
   He3TransmissionEmptyGlass
   PolarizationCorrectedData
   Polarized
   Polarizer
   SecondDegreePolynomialEfficiency
   SupermirrorEfficiencyFunction
   Up
```

## Top-level functions

```{eval-rst}
.. autosummary::
   :toctree: ../generated/functions
   :recursive:
```

## Submodules

```{eval-rst}
.. autosummary::
   :toctree: ../generated/modules
   :template: module-template.rst
   :recursive:
```
